//____________________________________________________________________________
/*!
 
\class   GAstro

\brief   A class for astronomical calculation 

\author  Carla Distefano <distefano_c@lns.infn.it>
         LNS-INFN, Catania

\created February 1, 2016

\cpright  Copyright (c) 2016-2019, The KM3NeT Collaboration
          For the full text of the license see $GSEAGEN/LICENSE
*/
//____________________________________________________________________________

#ifndef _GASTRO__
#define _GASTRO__

#include <iostream>
#include <string>

using namespace std;

class GAstro {

  public:
    GAstro(double Latitude, double Longitude);  
    ~GAstro(); 
    
    void SetCoordinates(double Latitude, double Longitude);
    
    double GST(double MJD);  	// returns GST in radians
    double LST(double MJD); 	// returns LST in radians
	
    void Eq2Hor(double LST, double RA, double Dec, double * Azimuth, double * Altitude);       
    void Hor2Eq(double Altitude, double Azimuth, double LST, double * RA, double * Dec);
    
    void Gal2Eq(string Equinox, double GalLat, double GalLong, double * RA, double * Dec);
    void Eq2Gal(string Equinox, double RA, double Dec, double * GalLat, double * GalLong);
    
    
    void Hor2Direction(double Azimuth, double Altitude, double * vx, double * vy, double * vz); 
    void Direction2Hor(double vx, double vy, double vz,double * Azimuth, double * Altitude);//// implementare
  

    void CalcPartDirMJD(double MJD, double RA, double Dec, double * vx, double * vy, double * vz);
    void CalcPartDirMJD(double MJD, double RA, double Dec, double * CosTheta, double * Phi);
    
    void CalcPartDirLST(double LST, double RA, double Dec, double * vx, double * vy, double * vz);
    void CalcPartDirLST(double LST, double RA, double Dec, double * CosTheta, double * Phi);    
    
    double CalcMJD(string Date); // Date in format dd-mm-yyyy,hh:mm:ss
    double CalcMJD(int month, int day, int hour, int min, int sec, int year);  
  private:
    
    double fLatitude;		// site latitude in rad
    double fLongitude;		// site longitude in rad, positive westwards from the meridian of Greenwich, and negative to the east.
};

#endif // _GASTRO__

































